# YT 2 AUDIO

<p align="right">
  <img src="https://img.shields.io/pypi/l/yt2audio"/>
  <img src="https://img.shields.io/pypi/pyversions/yt2audio"/>
  <img src="https://img.shields.io/pypi/wheel/yt2audio"/>
  <img src="https://img.shields.io/pypi/v/yt2audio"/>
</p>

<br>

<p align="center">
  <img src="https://github.com/isuruwa/YT2AUDIO/blob/main/docs/images/YT2AUDIO.png">
</p>
  
This program allows you to download high-quality audio from YouTube and YouTube Music.
 
## Prerequisites
```
ffmpeg
yt-dlp
```
## Features:
    - Supports high-quality audio downloads
    - Embeds thumbnail in audio file
    - Adds metadata to audio file
    - Verbose Mode
## Install
```
pip install yt2audio
```
## Usage: 
```
yt2audio [url]
```


#### Options:  
| Arguments             |                                                                     |
|-----------------------|---------------------------------------------------------------------|
| `-o, --output`        | Output directory for downloaded audio (default: current directory)  |
| `-f, --output-format` | Output audio format (default: mp3)                                  |
| `-v, --verbose`       | Enable verbose mode                                                 |
| `--about`             | About                                                               |
